Your message dated Mon, 15 Aug 2016 19:05:19 +0000
with message-id <[email protected]>
and subject line Bug#833912: Removed package(s) from unstable
has caused the Debian Bug report #777636,
regarding [PATCH] Wrong TGA header generated by j2k_to_image
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)


-- 
777636: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=777636
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: openjpeg-tools
Version: 1:1.5.2-3
Tags: patch

The TGA file writer used by j2k_to_image writes a wrong field to the
header for alpha-less images.

To reproduce:
1. Take any 24-bit j2k image with no alpha.
2. Convert it to TGA with j2k_to_image -i <image>.j2k -o <image>.tga
3. Open <image>.tga with Gimp.

When opened, the image will have a wrong alpha channel, because Gimp
uses a certain field in the header to determine if the image has alpha.
That field is saved wrongly by j2k_to_image for alpha-less images. Per
the TGA specification, Gimp is correct in this case.

The attached patch fixes this issue.
--- openjpeg-1.5.2/applications/codec/convert.c.orig	2014-03-27 11:58:06.000000000 +0100
+++ openjpeg-1.5.2/applications/codec/convert.c	2015-02-11 00:12:10.000000000 +0100
@@ -243,7 +243,10 @@
 
 	if(fwrite(&pixel_depth, 1, 1, fp) != 1) goto fails;
 
-	image_desc = 8; /* 8 bits per component. */
+	tga.image_desc = // bits 0-3 are # of alpha bits per pixel
+		bits_per_pixel == 16 ? 1 :
+		bits_per_pixel == 32 ? 8 :
+		0;
 
 	if (flip_image)
 		image_desc |= 32;

--- End Message ---
--- Begin Message ---
Version: 1:1.5.2-3.1+rm

Dear submitter,

as the package openjpeg has just been removed from the Debian archive
unstable we hereby close the associated bug reports.  We are sorry
that we couldn't deal with your issue properly.

For details on the removal, please see https://bugs.debian.org/833912

The version of this package that was in Debian prior to this removal
can still be found using http://snapshot.debian.org/.

This message was generated automatically; if you believe that there is
a problem with it please contact the archive administrators by mailing
[email protected].

Debian distribution maintenance software
pp.
Scott Kitterman (the ftpmaster behind the curtain)

--- End Message ---
_______________________________________________
Pkg-phototools-devel mailing list
[email protected]
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-phototools-devel

Reply via email to